# Legal Text

**Legal Text** is a Drupal module that allows site administrators to configure and display a customizable legal text for selected content types. The legal text can be added to the bottom of the content for specific content types as defined in the configuration.

## Features
- Configure a custom legal text through the administrative interface.
- Select specific content types to display the legal text.
- Cache invalidation ensures the legal text is updated immediately upon configuration change.

## Requirements
- Drupal 10 or Drupal 11
- No additional modules are required for this module to function.

## Installation
1. Download and install the module:
   ```bash
   composer require drupal/legal_text
   ```
   Or, download the module manually and place it in the modules/custom directory.
2. Enable the module via Drush or the Drupal Admin UI:
   ```bash
   drush en legal_text
   ```
3. Clear the cache:
   ```bash
   drush cr
   ```

## Configuration
1. Navigate to the configuration page:
   - Admin path: admin/config/content/legal-text
2. Configure the following options:
   - Legal Text: Enter the text that you want to display as the legal text.
   - Content Types: Select the content types where the legal text should be displayed.
   - Save the configuration. The legal text will now appear at the bottom of the content for the selected content types.

## Usage
- The module displays the configured legal text at the bottom of content for the selected content types.
- The notice is rendered via the hook_entity_view() implementation and cached accordingly.
- The cache is invalidated when the legal text configuration or selected content types are updated.

## Cache Management
The module integrates with Drupal's cache system. When the configuration is updated, the cache is invalidated automatically to ensure the updated legal text is displayed.
  - The module uses the cache tag config:legal_text.settings to invalidate the cached content when the configuration changes.

## Example Code
You can manually retrieve and display the legal text in your custom templates or code by loading the configuration:
   ```bash
   $config = \Drupal::service('config.factory')->get('legal_text.settings');
   $legal_text = $config->get('legal_text');
   ```
## Known Issues
Currently, the module supports only Node entities. Support for additional entity types can be extended by modifying the code in hook_entity_view().

## Maintainers
Mohammad Anwar Siddiqui - Maintainer and developer of the module.
